#include <stdint.h>
#include "built_in.h"

// TFT module connections
sbit TFT_BLED at GPIOA_PDOR.B4;
sbit TFT_CS at GPIOA_PDOR.B26;
char TFT_DataPort at GPIOD_PDOR;
sbit TFT_RD at GPIOA_PDOR.B28;
sbit TFT_RS at GPIOA_PDOR.B27;
sbit TFT_RST at GPIOA_PDOR.B25;
sbit TFT_WR at GPIOA_PDOR.B29;
// End TFT module connections

unsigned char adc_conv_res[12];
uint16_t ADC_Result = 0;

void Write_to_Data_Lines(unsigned char _hi, unsigned char _lo) {
  GPIOD_PDOR = (unsigned int) (_lo | (_hi << 8));
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  Write_to_Data_Lines(0, index);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  Write_to_Data_Lines(0, cmd);
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  Write_to_Data_Lines(Hi(_data), Lo(_data));
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

static void InitDisplay() {
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_SSD1963_Board_43(480, 272);
  TFT_Set_DBC_SSD1963(255);
  TFT_Fill_Screen(CL_WHITE);
  TFT_Write_Text("MM4 ADC KINETIS TEST",100,25);
  TFT_Write_Text("--------------------",100,40);
}

void main() {

   InitDisplay();
   ADC0_Init();                                                // Init ADC1
   ADC0_Set_Input_Channel(_ADC_CHANNEL_13);                    // Choose ADC channel 12 for PTB6
   Delay_ms(100);
   
     while(1) {
       ADC_Result = ADC0_Get_Sample(13);
       WordToStr(ADC_Result,adc_conv_res);
         TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
         TFT_Set_Pen(CL_WHITE,1);
         TFT_Rectangle(85,100,200,190);
         TFT_Write_Text(adc_conv_res, 85, 100);
       Delay_ms(10);
   }
}